/*
** lcd.h
**
** LCD 3310 driver
** Target: ATMEGA :: AVR-GCC
**
** Written by Tony Myatt - 2007
** Quantum Torque - www.quantumtorque.com
*/
#ifndef _NOKIALCD_H_
#define _NOKIALCD_H_

/* Lcd screen size */
#define LCD_X_RES 84
#define LCD_Y_RES 48
#define BYTE_SIZE 8
#define UNDEFINED -1
#define LCD_CACHE_SIZE ((LCD_X_RES * LCD_Y_RES) / 8)

/* Pinout for LCD */
#define LCD_CLK_PIN 	(1<<PC7)
#define LCD_DATA_PIN 	(1<<PC6)
#define LCD_DC_PIN 		(1<<PC5)
#define LCD_CE_PIN 		(1<<PC4)
#define LCD_RST_PIN 	(1<<PC3)
#define LCD_PORT		PORTC
#define LCD_DDR			DDRC

/* Special Chars */
#define ARROW_RIGHT	ICON(0)
#define ARROW_LEFT 	ICON(1)
#define ARROW_UP 	ICON(2)
#define ARROW_DOWN 	ICON(3)
#define STOP 		ICON(4)
#define PLAY	 	ICON(5)
#define BLOCK		ICON(6)
#define BALL		ICON(7)

/* Function for my special characters */
#define	ICON(x)		'z'+1+x

void lcd_init(void);
void lcd_contrast(unsigned char contrast);
void lcd_clear(void);
void lcd_clear_area(unsigned char line, unsigned char startX, unsigned char endX);
void lcd_clear_line(unsigned char line);
void lcd_goto_xy(unsigned char x, unsigned char y);
void lcd_goto_xy_exact(unsigned char x, unsigned char y);
void lcd_goto_xy_pixel(unsigned char x, unsigned char y);
void lcd_chr(char chr);
void lcd_chr_unspaced(char chr);
void lcd_str(char* str);
void clear_left_column(void);
void clear_right_column(void);
void draw_platform(void);

#endif



